//
//  ViewController.m
//  RCChangeFlowLayout
//
//  Created by RongCheng on 2019/4/28.
//  Copyright © 2019年 RongCheng. All rights reserved.
//

#import "ViewController.h"
#import "CollectionViewCell.h"
#define  ScreenHeight [UIScreen mainScreen].bounds.size.height
#define  ScreenWidth  [UIScreen mainScreen].bounds.size.width
@interface ViewController ()<UICollectionViewDelegate,UICollectionViewDataSource>
@property (nonatomic,strong)UICollectionView *collectionView;
@property (nonatomic, strong) UICollectionViewFlowLayout *gridLayout;
@property (nonatomic, strong) UICollectionViewFlowLayout *listLayout;
@property (nonatomic, assign)BOOL isList;
@end

@implementation ViewController

static NSString *const CollectionViewCellID = @"CollectionViewCellID";

-(UICollectionViewFlowLayout *)gridLayout{
    if (!_gridLayout) {
        _gridLayout = [[UICollectionViewFlowLayout alloc] init];
        CGFloat width = floorf((ScreenWidth - 30) * 0.5);
        _gridLayout.itemSize = CGSizeMake(width, width+80);
        _gridLayout.minimumLineSpacing = 10;
        _gridLayout.minimumInteritemSpacing = 10;
        _gridLayout.sectionInset = UIEdgeInsetsMake(10, 10, 10, 10);
    }
    return _gridLayout;
}

-(UICollectionViewFlowLayout *)listLayout{
    if (!_listLayout) {
        _listLayout = [[UICollectionViewFlowLayout alloc] init];
        _listLayout.itemSize = CGSizeMake(ScreenWidth-20, 100);
        _listLayout.minimumLineSpacing = 10;
        _listLayout.sectionInset = UIEdgeInsetsMake(10, 10, 10, 10);
    }
    return _listLayout;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    self.view.backgroundColor = [UIColor whiteColor];
    
    UICollectionView *collect = [[UICollectionView alloc]initWithFrame:CGRectMake(0, 0, ScreenWidth,ScreenHeight) collectionViewLayout:self.gridLayout];
    collect.backgroundColor = [UIColor whiteColor];
    collect.delegate = self;
    collect.dataSource = self;
    [collect registerClass:[CollectionViewCell class] forCellWithReuseIdentifier:CollectionViewCellID];
    if (@available(iOS 11.0, *)) {
        collect.contentInsetAdjustmentBehavior = UIScrollViewContentInsetAdjustmentNever;
    } else {
        self.automaticallyAdjustsScrollViewInsets = NO;
        
    }
    [self.view addSubview:collect];
    self.collectionView = collect;
    
    UIButton *btn = [UIButton buttonWithType:UIButtonTypeCustom];
    btn.frame = CGRectMake(ScreenWidth-50, 20, 44, 44);
    btn.backgroundColor = [UIColor redColor];
    [btn setTitle:@"切换" forState:(UIControlStateNormal)];
    btn.titleLabel.font = [UIFont systemFontOfSize:15];
    [btn addTarget:self action:@selector(changeClick:) forControlEvents:(UIControlEventTouchUpInside)];
    [self.view addSubview:btn];
}

- (void)changeClick:(UIButton *)sender{

    _isList = !_isList;

    NSArray *array = [self.collectionView indexPathsForVisibleItems];
    for(NSIndexPath *indexPath in array){
        CollectionViewCell *cell = (CollectionViewCell*) [self.collectionView cellForItemAtIndexPath:indexPath];
        cell.animation = YES;
        cell.isList = _isList;
    }
    
    if (_isList) {
        [self.collectionView setCollectionViewLayout:self.listLayout animated:YES];
    }else{
        [self.collectionView setCollectionViewLayout:self.gridLayout animated:YES];
    }  
}


- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section{
    return 100;
}

- (UICollectionViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath{
    CollectionViewCell *cell = [collectionView dequeueReusableCellWithReuseIdentifier:CollectionViewCellID forIndexPath:indexPath];
    cell.animation = NO;
    cell.isList = _isList;
    return cell;
}

@end
